@@ -49,19 +49,22 @@ function sitebuilder_uvt_mediamosa_ck_views_theme_asset_metadata($variables) {
     if ($name == 'source') {
       $name = t('Retention period');
     }
+    $name = drupal_ucfirst(str_replace('_', ' ', $name));
+
+    if (is_array($value)) {
+      $value = implode("\n", $value);
+    }
     if (($name == 'created') and (isset($value)) and (substr($value, -9) == ' 00:00:00')) {
       $value = substr($value, 0, -9);
     }
-    $name = drupal_ucfirst(str_replace('_', ' ', $name));
+
     if (empty($value)) {
       $rows[] = array(
         'class' => array('empty'), 'data' => array('name' => $name, 'value' => ''),
       );
     }
     else {
-      $rows[] = array(
-        'data' => array('name' => $name, 'value' => nl2br(check_plain($value))),
-      );
+      $rows[] = array('name' => $name, 'value' => (empty($value) ? ' ' : nl2br(check_plain($value))));
     }
   }
   if (empty($rows)) {
